Welcome to Rmdawn's documentation!
======================================================

.. toctree::
   :maxdepth: 2
   :caption: Contents:

   Project overview <readme.rst>
   Command-line interface <cli.rst>
   Module reference <modules.rst>
   Test reference <tests.rst>





Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
